Typedef
=======

.. toctree::
   :hidden:
   :maxdepth: 2

Frame
-----

.. currentmodule:: fastobo.typedef
.. automodule:: fastobo.typedef

.. autoclass:: TypedefFrame(AbstractEntityFrame)
   :members:
   :special-members:


Clauses
-------

.. autoclass:: BaseTypedefClause(AbstractEntityClause)
   :members:
   :special-members:

.. autoclass:: AltIdClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: BuiltinClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: CommentClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: ConsiderClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: CreatedByClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: CreationDateClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: DefClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: DisjointFromClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: DisjointOverClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: DomainClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: EquivalentToChainClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: EquivalentToClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: ExpandAssertionToClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: ExpandExpressionToClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: HoldsOverChainClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IntersectionOfClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: InverseOfClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsAClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsAnonymousClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsAntiSymmetricClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsAsymmetricClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsClassLevelClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsCyclicClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsFunctionalClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsInverseFunctionalClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsMetadataTagClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsObsoleteClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsReflexiveClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsSymmetricClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: IsTransitiveClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: NameClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: NamespaceClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: PropertyValueClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: RangeClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: RelationshipClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: ReplacedByClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: SubsetClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: SynonymClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: TransitiveOverClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: UnionOfClause(BaseTypedefClause)
  :members:
  :special-members:

.. autoclass:: XrefClause(BaseTypedefClause)
  :members:
  :special-members:
